aboutsummaryrefslogtreecommitdiff
path: root/libbuild2/cc/link-rule.hxx
diff options
context:
space:
mode:
authorBoris Kolpackov <boris@codesynthesis.com>2019-10-29 09:05:26 +0200
committerBoris Kolpackov <boris@codesynthesis.com>2019-10-29 09:05:26 +0200
commitbb2ad1820e3f1811edd8ab11ee0cbe4d19908367 (patch)
treed26b6b0ed475d43f569863885ee933f4a8a7a597 /libbuild2/cc/link-rule.hxx
parent1c660edff6785e4b7bb66bb4b33aef54cebb190e (diff)
Tighten up versioned libraries clean patterns
Diffstat (limited to 'libbuild2/cc/link-rule.hxx')
-rw-r--r--libbuild2/cc/link-rule.hxx10
1 files changed, 6 insertions, 4 deletions
diff --git a/libbuild2/cc/link-rule.hxx b/libbuild2/cc/link-rule.hxx
index 07e619d..84d3195 100644
--- a/libbuild2/cc/link-rule.hxx
+++ b/libbuild2/cc/link-rule.hxx
@@ -64,7 +64,7 @@ namespace build2
//
// Note that the paths must form a "hierarchy" with subsequent paths
// adding extra information as suffixes. This is relied upon by the
- // clean pattern (see below).
+ // clean patterns (see below).
//
// The libs{} path is always the real path. On Windows what we link
// to is the import library and the link path is empty.
@@ -81,11 +81,13 @@ namespace build2
inline const path&
effect_soname () const {return soname.empty () ? *real : soname;}
// Cleanup pattern used to remove previous versions. If empty, no
// cleanup is performed. The above (current) names are automatically
// filtered out.
//
- path clean;
+ path clean_load;
+ path clean_version;
};
libs_paths
@@ -81,11 +81,13 @@ namespace build2
inline const path&
effect_soname () const {return soname.empty () ? *real : soname;}
- // Cleanup pattern used to remove previous versions. If empty, no
- // cleanup is performed. The above (current) names are automatically
+ // Cleanup patterns used to remove previous load suffixes/versions.
+ // If empty, no corresponding cleanup is performed. The current names
+ // as well as names with the real path as a prefix are automatically
// filtered out.
//